# Kubetools Client

Client to handle development of Docker based apps from local to production. `kubetools` has two main functions:

+ **local dev**: use `ktd` to start/stop/test development environments for Docker apps
+ **deployment**: use `kubetools` to deploy Docker apps to Kubernetes clusters (staging/production)

## Installing

```sh
pip install kubetools
```

## Developing

Install the package in editable mode, with the dev extras:

```sh
pip install -e .[dev]
```
